@@ -14,14 +14,19 @@
  * limitations under the License.
  *
  */
-#include "gz/rendering/ogre2/Ogre2RenderPass.hh"
+#include "ignition/rendering/ogre2/Ogre2RenderPass.hh"
 
+/// \brief Private data for the Ogre2RenderPass class
+class ignition::rendering::Ogre2RenderPassPrivate
+{
+};
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
 Ogre2RenderPass::Ogre2RenderPass()
+  : dataPtr(std::make_unique<Ogre2RenderPassPrivate>())
 {
 }
 
