@@ -14,9 +14,9 @@
  * limitations under the License.
  *
  */
-#include "gz/rendering/optix/OptixBox.hh"
+#include "ignition/rendering/optix/OptixBox.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
